package com.adventurer_engine.common.gadgets;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import by;
import cd;
import cg;
import com.adventurer_engine.AdventurerEngine;
import com.adventurer_engine.common.PlayerTools;
import com.adventurer_engine.common.gadgets.AdditionBombs;
import com.adventurer_engine.util.JsonHelper;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import nb;
import nc;
import nj;
import nn;
import of;
import uf;

public class DamagePacket {
  private static final Map<Integer, com.adventurer_engine.common.gadgets.DamagePacket> PACKETS = new HashMap<Integer, com.adventurer_engine.common.gadgets.DamagePacket>();
  
  private final float flu;
  
  private final float bomb_damage;
  
  private final int bomb_delay;
  
  private final String bomb_sound;
  
  private final boolean hasBomb;
  
  private final int bombAmount;
  
  private final nj[] effect_wounded;
  
  private final float[] p_effect_wounded;
  
  private final nj[] effect_attacker;
  
  private final float[] p_effect_attacker;
  
  public DamagePacket(JsonHelper json) {
    this.flu = json.hasKey("fluctuating") ? json.getFloat("fluctuating") : 0.0F;
    if (json.hasKey("bomb")) {
      JsonHelper bombJson = json.getSubJson("bomb");
      this.bomb_damage = bombJson.getFloat("damage");
      this.bomb_delay = bombJson.getInt("delay");
      this.bomb_sound = bombJson.hasKey("sound") ? bombJson.getString("sound") : null;
      AdventurerEngine.proxy.addSound(this.bomb_sound);
      this.hasBomb = true;
    } else {
      this.bomb_damage = 0.0F;
      this.bomb_delay = 0;
      this.bomb_sound = null;
      this.hasBomb = false;
    } 
    this.bombAmount = json.hasKey("bomb_amount") ? json.getInt("bomb_amount") : 0;
    if (json.hasKey("effect_wounded")) {
      List<Double> effects = json.getList("effect_wounded");
      this.effect_wounded = parseEffects(effects);
      if (json.hasKey("p_effect_wounded")) {
        effects = json.getList("p_effect_wounded");
        this.p_effect_wounded = new float[effects.size()];
        for (int i = 0; i < effects.size(); i++)
          this.p_effect_wounded[i] = ((Double)effects.get(i)).floatValue(); 
      } else {
        this.p_effect_wounded = null;
      } 
    } else {
      this.effect_wounded = null;
      this.p_effect_wounded = null;
    } 
    if (json.hasKey("effect_attacker")) {
      List<Double> effects = json.getList("effect_attacker");
      this.effect_attacker = parseEffects(effects);
      if (json.hasKey("p_effect_attacker")) {
        effects = json.getList("p_effect_attacker");
        this.p_effect_attacker = new float[effects.size()];
        for (int i = 0; i < effects.size(); i++)
          this.p_effect_attacker[i] = ((Double)effects.get(i)).floatValue(); 
      } else {
        this.p_effect_attacker = null;
      } 
    } else {
      this.effect_attacker = null;
      this.p_effect_attacker = null;
    } 
  }
  
  public DamagePacket(by nbt) {
    this.flu = nbt.b("fluctuating") ? (float)nbt.h("fluctuating") : 0.0F;
    this.bomb_damage = nbt.b("bomb_damage") ? (float)nbt.h("bomb_damage") : 0.0F;
    this.bomb_delay = nbt.b("bomb_delay") ? nbt.e("bomb_delay") : 0;
    this.bomb_sound = nbt.b("bomb_sound") ? nbt.i("bomb_sound") : null;
    this.bombAmount = nbt.b("bomb_amount") ? nbt.e("bomb_amount") : 0;
    this.hasBomb = (this.bomb_damage != 0.0F);
    if (nbt.b("effect_wounded")) {
      this.effect_wounded = parseEffects(nbt.k("effect_wounded"));
      if (nbt.b("p_effect_wounded")) {
        cg ls = nbt.m("p_effect_wounded");
        this.p_effect_wounded = new float[ls.c()];
        for (int i = 0; i < this.p_effect_wounded.length; i++)
          this.p_effect_wounded[i] = ((cd)ls.b(i)).a; 
      } else {
        this.p_effect_wounded = null;
      } 
    } else {
      this.effect_wounded = null;
      this.p_effect_wounded = null;
    } 
    if (nbt.b("effect_attacker")) {
      this.effect_attacker = parseEffects(nbt.k("effect_attacker"));
      if (nbt.b("p_effect_attacker")) {
        cg ls = nbt.m("p_effect_attacker");
        this.p_effect_attacker = new float[ls.c()];
        for (int i = 0; i < this.p_effect_attacker.length; i++)
          this.p_effect_attacker[i] = ((cd)ls.b(i)).a; 
      } else {
        this.p_effect_attacker = null;
      } 
    } else {
      this.effect_attacker = null;
      this.p_effect_attacker = null;
    } 
    PACKETS.put(Integer.valueOf(nbt.e("packet_id")), this);
  }
  
  private static nj[] parseEffects(List<Double> arr) {
    nj[] effects = new nj[arr.size() / 3];
    for (int i = 0; i < arr.size(); i += 3)
      effects[i / 3] = new nj(((Double)arr.get(i)).intValue(), ((Double)arr.get(i + 1)).intValue(), ((Double)arr.get(i + 2)).intValue()); 
    return effects;
  }
  
  private static nj[] parseEffects(int[] arr) {
    nj[] effects = new nj[arr.length / 3];
    for (int i = 0; i < arr.length; i += 3)
      effects[i / 3] = new nj(arr[i], arr[i + 1], arr[i + 2]); 
    return effects;
  }
  
  private AdditionBombs getBomb(uf player, int stage) {
    return (new AdditionBombs()).setDamage(this.bomb_damage).setDelay(this.bomb_delay * stage).setSound("adventurer_engine:" + this.bomb_sound).setAttacker((of)player);
  }
  
  public boolean causeDamage(uf attacker, of wounded, float basic_damage, float ice_damage, nb dmg) {
    basic_damage = (this.flu == 0.0F) ? basic_damage : PlayerTools.randomGaussian(basic_damage, this.flu);
    if (this.hasBomb)
      for (int i = 0; i < this.bombAmount; i++)
        AdditionBombs.addBomb(wounded, getBomb(attacker, i + 1));  
    buffGiver(wounded, this.effect_wounded, this.p_effect_wounded);
    buffGiver((of)attacker, this.effect_attacker, this.p_effect_attacker);
    boolean toRet = true;
    if (basic_damage > 0.0F) {
      toRet = wounded.a(dmg, basic_damage);
      wounded.af = 0;
    } 
    if (ice_damage > 0.0F) {
      toRet |= wounded.a((nb)new nc("ice_damage", (nn)attacker), ice_damage);
      wounded.af = 0;
    } 
    return toRet;
  }
  
  public boolean causeDamage(uf attacker, of wounded, float[] damages, float[] defenses) {
    int len = Math.min(damages.length, defenses.length);
    int i;
    for (i = 0; i < len; i++) {
      damages[i] = (this.flu == 0.0F) ? damages[i] : PlayerTools.randomGaussian(damages[i], this.flu);
      damages[i] = damages[i] * defenses[i];
    } 
    if (this.hasBomb)
      for (i = 0; i < this.bombAmount; i++)
        AdditionBombs.addBomb(wounded, getBomb(attacker, i));  
    if (this.effect_wounded != null)
      buffGiver(wounded, this.effect_wounded, this.p_effect_wounded); 
    if (this.effect_attacker != null)
      buffGiver((of)attacker, this.effect_attacker, this.p_effect_attacker); 
    boolean flag = false;
    for (int j = 0; j < len; j++)
      flag = (wounded.a(nb.a(attacker), damages[j]) || flag); 
    return flag;
  }
  
  private void buffGiver(of target, nj[] effects, float[] percent) {
    if (effects == null)
      return; 
    if (percent == null) {
      for (nj effect : effects)
        target.c(new nj(effect)); 
    } else {
      if (percent.length < effects.length)
        return; 
      for (int i = 0; i < effects.length; i++) {
        if (PlayerTools.percent(percent[i]))
          target.c(new nj(effects[i])); 
      } 
    } 
  }
  
  public static com.adventurer_engine.common.gadgets.DamagePacket getPacket(int id) {
    return PACKETS.get(Integer.valueOf(id));
  }
}
